@@ -30,12 +30,18 @@
 #include "utils.h"
 
 #define PASSWORD "Open, Sesame"
-#define USERNAME "Ali Baba"
-/* "Ali " "\xC2\xAD" "Bab" "\xC2\xAA" */
-/* "Al\xC2\xAA""dd\xC2\xAD""in\xC2\xAE" */
-#define AUTHZID "joe"
 
-#define EXPECTED_USERNAME "Ali Baba"
+#define N_AUTHID 4
+static const char *AUTHID[N_AUTHID] = {
+  "Ali Baba", "BAB,ABA", ",=,=", "="
+  /* "Ali " "\xC2\xAD" "Bab" "\xC2\xAA" */
+  /* "Al\xC2\xAA""dd\xC2\xAD""in\xC2\xAE" */
+};
+
+#define N_AUTHZID 4
+static const char *AUTHZID[N_AUTHZID] = {
+  "jas", "BAB,ABA", ",=,=", "="
+};
 
 size_t i;
 
@@ -54,21 +60,21 @@ callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
       break;
 
     case GSASL_AUTHID:
-      gsasl_property_set (sctx, prop, USERNAME);
+      gsasl_property_set (sctx, prop, AUTHID[i % N_AUTHID]);
       rc = GSASL_OK;
       break;
 
     case GSASL_AUTHZID:
       if (i & 0x01)
 	{
-	  gsasl_property_set (sctx, prop, AUTHZID);
+	  gsasl_property_set (sctx, prop, AUTHZID[i % N_AUTHZID]);
 	  rc = GSASL_OK;
 	}
       break;
 
     case GSASL_SCRAM_ITER:
       if (strcmp (gsasl_property_fast (sctx, GSASL_AUTHID),
-		  EXPECTED_USERNAME) != 0)
+		  AUTHID[i % N_AUTHID]) != 0)
 	fail ("Username mismatch: %s",
 	      gsasl_property_fast (sctx, GSASL_AUTHID));
       if (i & 0x02)
@@ -219,7 +225,26 @@ doit (void)
 	}
 
       if (debug)
-	printf ("C: %.*s\n\n", s1len, s1);
+	printf ("C: %.*s\n", s1len, s1);
+
+      {
+	const char *p = gsasl_property_fast (server, GSASL_AUTHID);
+	if (p && strcmp (p, AUTHID[i % N_AUTHID]) != 0)
+	  fail ("Bad authid? %s != %s\n", p, AUTHID[i % N_AUTHID]);
+	if (i & 0x01 && !p)
+	  fail ("Expected authid? %d/%s\n", i, AUTHID[i % N_AUTHID]);
+      }
+
+      {
+	const char *p = gsasl_property_fast (server, GSASL_AUTHZID);
+	if (p && strcmp (p, AUTHZID[i % N_AUTHZID]) != 0)
+	  fail ("Bad authzid? %s != %s\n", p, AUTHZID[i % N_AUTHZID]);
+	if (i & 0x01 && !p)
+	  fail ("Expected authzid? %d/%s\n", i, AUTHZID[i % N_AUTHZID]);
+      }
+
+      if (debug)
+	printf ("\n");
 
       gsasl_finish (client);
       gsasl_finish (server);
